@@ -1,4 +1,4 @@
-from keras_cv_attention_models.botnet.botnet import BotNet, BotNet50, BotNet101, BotNet152, BotNet26T, BotNextECA26T, RelativePositionalEmbedding, mhsa_with_relative_position_embedding
+from keras_cv_attention_models.botnet.botnet import BotNet, BotNet50, BotNet101, BotNet152, BotNet26T, BotNextECA26T, BotNetSE33T, RelativePositionalEmbedding, mhsa_with_relative_position_embedding
 
 
 __head_doc__ = """
@@ -38,6 +38,7 @@ Model architectures:
   | BotNet152     | 56M    | 224              |          |
   | BotNet26T     | 12.5M  | 256              | 79.246   |
   | BotNextECA26T | 10.59M | 256              | 79.270   |
+  | BotNetSE33T   | 13.7M  | 256              | 81.2     |
 """
 
 BotNet50.__doc__ = __head_doc__ + """
@@ -52,6 +53,7 @@ BotNet26T.__doc__ = __head_doc__ + """Model weights are reloaded from timm [Gith
 Args:
 """ + __tail_doc__
 BotNextECA26T.__doc__ = BotNet26T.__doc__
+BotNetSE33T.__doc__ = BotNet26T.__doc__
 
 mhsa_with_relative_position_embedding.__doc__ = __head_doc__ + """
 Multi head self attention with positional embedding. Defined as function, not layer.
