@@ -5,7 +5,11 @@ import tensorflow as tf
 def __compute_loss__(feature_extractor, input_image, filter_index):
     activation = feature_extractor(input_image)
     # We avoid border artifacts by only involving non-border pixels in the loss.
-    filter_activation = activation[:, 2:-2, 2:-2, filter_index]
+    # filter_activation = activation[:, 2:-2, 2:-2, filter_index]
+    if len(activation.shape) == 4:
+        filter_activation = activation[:, 2:-2, 2:-2, filter_index]
+    else:
+        filter_activation = activation[..., filter_index]
     return tf.reduce_mean(filter_activation)
 
 
@@ -116,9 +120,15 @@ def visualize_filters(model, layer_name, filter_index_list=[0], input_shape=None
     return losses, np.stack(filter_images), ax
 
 
-def make_gradcam_heatmap(model, img_array, layer_name, pred_index=None):
+def make_gradcam_heatmap(model, img_array, layer_name="auto", pred_index=None):
     # First, we create a model that maps the input image to the activations
     # of the last conv layer as well as the output predictions
+    if layer_name == "auto":
+        for ii in model.layers[::-1]:
+            if len(ii.output_shape) == 4:
+                layer_name = ii.name
+                print("Using layer_name:", layer_name)
+                break
     grad_model = tf.keras.models.Model(model.inputs[0], [model.get_layer(layer_name).output, model.output])
 
     # Then, we compute the gradient of the top predicted class for our input image
@@ -151,10 +161,12 @@ def make_gradcam_heatmap(model, img_array, layer_name, pred_index=None):
     return heatmap.numpy().astype("float32"), preds.numpy()
 
 
-def make_and_apply_gradcam_heatmap(model, image, layer_name, rescale_mode="tf", pred_index=None, alpha=0.4, plot=True):
+def make_and_apply_gradcam_heatmap(model, image, layer_name="auto", rescale_mode="tf", pred_index=None, alpha=0.8, plot=True):
     import matplotlib.cm as cm
     import matplotlib.pyplot as plt
 
+    image = np.array(image)
+    image = image * 255 if image.max() < 2 else image  # Makse sure it's [0, 255]
     processed_image = tf.expand_dims(tf.image.resize(image, model.input_shape[1:-1]), 0)
     processed_image = tf.keras.applications.imagenet_utils.preprocess_input(processed_image, mode=rescale_mode)
     heatmap, preds = make_gradcam_heatmap(model, processed_image, layer_name, pred_index=pred_index)
@@ -168,13 +180,13 @@ def make_and_apply_gradcam_heatmap(model, image, layer_name, rescale_mode="tf",
     jet_heatmap = tf.image.resize(jet_heatmap, (image.shape[:2]))  # [0, 1]
 
     # Superimpose the heatmap on original image
-    image = image.astype("float32") / 255 if image.max() > 127 else image
+    image = image.astype("float32") / 255
     superimposed_img = (jet_heatmap * alpha + image).numpy()
     superimposed_img /= superimposed_img.max()
 
     if model.output_shape[-1] == 1000:
         print(">>>> Prediction:", tf.keras.applications.imagenet_utils.decode_predictions(preds)[0])
-        print(">>>> Top 5 prediction indexes:", np.argsort(preds[0])[-5:])
+        print(">>>> Top 5 prediction indexes:", np.argsort(preds[0])[-5:][::-1])
     if plot:
         fig = plt.figure()
         plt.imshow(superimposed_img)
@@ -280,8 +292,8 @@ def plot_attention_score_maps(model, image, rescale_mode="tf", attn_type="auto",
         print(">>>> Attention type: coatnet")
         mask = [np.array(ii)[0].mean((0)) for ii in attn_scores if len(ii.shape) == 4][::-1]
         cum_mask = [mask[0]] + [down_sample_matrix_axis_0(mask[ii], mask[ii - 1].shape[1], "max") for ii in range(1, len(mask))]
-        cum_mask = [matmul_prod(cum_mask[: ii + 1]).max(0) for ii in range(len(cum_mask))]
-        mask = [ii.max(0) for ii in mask]
+        cum_mask = [matmul_prod(cum_mask[: ii + 1]).mean(0) for ii in range(len(cum_mask))]
+        mask = [ii.mean(0) for ii in mask]
     elif check_type_is("halo"):
         # halo attn_score [batch, num_heads, hh, ww, query_block * query_block, kv_kernel * kv_kernel]
         print(">>>> Attention type: halo")
